@@ -9,14 +9,14 @@ use warnings;
 #use bytes;
 
 use IO::File;
-use IO::Uncompress::RawInflate  2.069 ;
-use IO::Compress::Base::Common  2.069 qw(:Status );
-use IO::Uncompress::Adapter::Inflate  2.069 ;
-use IO::Uncompress::Adapter::Identity 2.069 ;
-use IO::Compress::Zlib::Extra 2.069 ;
-use IO::Compress::Zip::Constants 2.069 ;
+use IO::Uncompress::RawInflate  2.070 ;
+use IO::Compress::Base::Common  2.070 qw(:Status );
+use IO::Uncompress::Adapter::Inflate  2.070 ;
+use IO::Uncompress::Adapter::Identity 2.070 ;
+use IO::Compress::Zlib::Extra 2.070 ;
+use IO::Compress::Zip::Constants 2.070 ;
 
-use Compress::Raw::Zlib  2.069 () ;
+use Compress::Raw::Zlib  2.070 () ;
 
 BEGIN
 {
@@ -31,7 +31,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnzipError, %headerLookup);
 
-$VERSION = '2.069';
+$VERSION = '2.070';
 $UnzipError = '';
 
 @ISA    = qw(Exporter IO::Uncompress::RawInflate);
@@ -1839,21 +1839,21 @@ L<Archive::Tar|Archive::Tar>,
 L<IO::Zlib|IO::Zlib>
 
 For RFC 1950, 1951 and 1952 see 
-F<http://www.faqs.org/rfcs/rfc1950.html>,
-F<http://www.faqs.org/rfcs/rfc1951.html> and
-F<http://www.faqs.org/rfcs/rfc1952.html>
+L<http://www.faqs.org/rfcs/rfc1950.html>,
+L<http://www.faqs.org/rfcs/rfc1951.html> and
+L<http://www.faqs.org/rfcs/rfc1952.html>
 
 The I<zlib> compression library was written by Jean-loup Gailly
-F<gzip@prep.ai.mit.edu> and Mark Adler F<madler@alumni.caltech.edu>.
+C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
 
 The primary site for the I<zlib> compression library is
-F<http://www.zlib.org>.
+L<http://www.zlib.org>.
 
-The primary site for gzip is F<http://www.gzip.org>.
+The primary site for gzip is L<http://www.gzip.org>.
 
 =head1 AUTHOR
 
-This module was written by Paul Marquess, F<pmqs@cpan.org>. 
+This module was written by Paul Marquess, C<pmqs@cpan.org>. 
 
 =head1 MODIFICATION HISTORY
 
@@ -1861,7 +1861,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2015 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2016 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
